@@ -35,10 +35,11 @@ import os.path
 
 import tables
 import numpy as np
-import progressbar as pb
+from progressbar import ProgressBar, ETA, Bar, Percentage
 
-from sapphire.analysis import process_events
-from sapphire import storage
+from . import process_events
+from .. import storage
+from ..utils import pbar
 
 
 class Coincidences(object):
@@ -91,7 +92,7 @@ class Coincidences(object):
                                        coincidence_group)
             head, tail = os.path.split(coincidence_group)
             self.coincidence_group = data.create_group(head, tail,
-                                                      createparents=True)
+                                                       createparents=True)
         self.station_groups = station_groups
 
         self.trig_threshold = .5
@@ -146,10 +147,10 @@ class Coincidences(object):
             self._search_coincidences(window, shifts, limit)
         timestamps = np.array(timestamps, dtype=np.uint64)
         self.data.create_array(self.coincidence_group, '_src_timestamps',
-                              timestamps)
+                               timestamps)
         src_c_index = self.data.create_vlarray(self.coincidence_group,
-                                              '_src_c_index',
-                                              tables.UInt32Atom())
+                                               '_src_c_index',
+                                               tables.UInt32Atom())
         for coincidence in c_index:
             src_c_index.append(coincidence)
 
@@ -208,20 +209,16 @@ class Coincidences(object):
 
         self.c_index = []
         self.coincidences = self.data.create_table(self.coincidence_group,
-                                                  'coincidences',
-                                                  storage.Coincidence)
+                                                   'coincidences',
+                                                   storage.Coincidence)
         self.observables = self.data.create_table(self.coincidence_group,
-                                                 'observables',
-                                                 storage.EventObservables)
+                                                  'observables',
+                                                  storage.EventObservables)
 
         # ProgressBar does not work for empty iterables.
         if len(self.coincidence_group._src_c_index):
-            if self.progress:
-                progress = pb.ProgressBar(widgets=[pb.Percentage(), pb.Bar(),
-                                                   pb.ETA()])
-                src_c_index = progress(self.coincidence_group._src_c_index)
-            else:
-                src_c_index = self.coincidence_group._src_c_index
+            src_c_index = pbar(self.coincidence_group._src_c_index,
+                               show=self.progress)
             for coincidence in src_c_index:
                 self._store_coincidence(coincidence)
         else:
@@ -230,7 +227,7 @@ class Coincidences(object):
                 self._store_coincidence(coincidence)
 
         c_index = self.data.create_vlarray(self.coincidence_group, 'c_index',
-                                          tables.UInt32Col())
+                                           tables.UInt32Col())
         for coincidence in self.c_index:
             c_index.append(coincidence)
         c_index.flush()
@@ -338,7 +335,8 @@ class Coincidences(object):
         for station_group in self.station_groups:
             station_group = self.data.get_node(station_group)
             if 'events' in station_group:
-                event_tables.append(self.data.get_node(station_group, 'events'))
+                event_tables.append(self.data.get_node(station_group,
+                                                       'events'))
         stations = event_tables
 
         # calculate the shifts in nanoseconds and cast them to long.
@@ -417,9 +415,8 @@ class Coincidences(object):
         prev_coincidence = []
 
         if self.progress and len(timestamps):
-            progress = pb.ProgressBar(maxval=len(timestamps),
-                                      widgets=[pb.Percentage(), pb.Bar(),
-                                               pb.ETA()]).start()
+            pbar = ProgressBar(maxval=len(timestamps),
+                               widgets=[Percentage(), Bar(), ETA()]).start()
 
         for i in xrange(len(timestamps)):
 
@@ -447,10 +444,10 @@ class Coincidences(object):
                     prev_coincidence = c
 
             if self.progress and not i % 5000:
-                progress.update(i)
+                pbar.update(i)
 
         if self.progress and len(timestamps):
-            progress.finish()
+            pbar.finish()
 
         return coincidences
 
@@ -509,16 +506,11 @@ class CoincidencesESD(Coincidences):
         description = storage.Coincidence
         description.columns.update(s_columns)
         self.coincidences = self.data.create_table(self.coincidence_group,
-                                                  'coincidences', description)
+                                                   'coincidences', description)
 
         # ProgressBar does not work for empty iterables.
         if len(self._src_c_index):
-            if self.progress:
-                progress = pb.ProgressBar(widgets=[pb.Percentage(), pb.Bar(),
-                                                   pb.ETA()])
-                src_c_index = progress(self._src_c_index)
-            else:
-                src_c_index = self._src_c_index
+            src_c_index = pbar(self._src_c_index, show=self.progress)
             for coincidence in src_c_index:
                 self._store_coincidence(coincidence)
         else:
@@ -527,14 +519,14 @@ class CoincidencesESD(Coincidences):
                 self._store_coincidence(coincidence)
 
         c_index = self.data.create_vlarray(self.coincidence_group, 'c_index',
-                                          tables.UInt32Col(shape=2))
+                                           tables.UInt32Col(shape=2))
         for coincidence in self.c_index:
             c_index.append(coincidence)
         c_index.flush()
         self.c_index = c_index
 
         s_index = self.data.create_vlarray(self.coincidence_group, 's_index',
-                                          tables.VLStringAtom())
+                                           tables.VLStringAtom())
         for station_group in self.station_groups:
             s_index.append(station_group)
         s_index.flush()
